FDIC: Failed Bank List
Author: DRR
Keywords: banks, financial institutions, failed, failure, closing, deposits, depositors, banking services, assuming institution, acquiring institution, claims

Skip Header

# Failed Bank List

The FDIC is often appointed as receiver for failed banks. This page contains useful information for the customers and vendors of these banks. This includes information on the acquiring bank (if applicable), how your accounts and loans are affected, and how vendors can file claims against the receivership. Failed Financial Institution Contact Search displays point of contact information related to failed banks.

This list includes banks which have failed since October 1, 2000. To search for banks that failed prior to those on this page, visit this link: Failures and Assistance Transactions

Failed Bank List - CSV file (Updated on Mondays. Also opens in Excel - Excel Help)

Due to the small screen size some information is no longer visible.
Full information available when viewed on a larger screen.

Bank Name | City | ST | CERT | Acquiring Institution | Closing Date | Updated Date
--- | --- | --- | --- | --- | --- | ---
Banks of Wisconsin d/b/a Bank of Kenosha | Kenosha | WI | 35386 | North Shore Bank, FSB | May 31, 2013 | May 31, 2013
Central Arizona Bank | Scottsdale | AZ | 34527 | Western State Bank | May 14, 2013 | May 20, 2013
Sunrise Bank | Valdosta | GA | 58185 | Synovus Bank | May 10, 2013 | May 21, 2013
Pisgah Community Bank | Asheville | NC | 58701 | Capital Bank, N.A. | May 10, 2013 | May 14, 2013
Douglas County Bank | Douglasville | GA | 21649 | Hamilton State Bank | April 26, 2013 | May 16, 2013
Parkway Bank | Lenoir | NC | 57158 | CertusBank, National Association | April 26, 2013 | May 17, 2013
Chipola Community Bank | Marianna | FL | 58034 | First Federal Bank of Florida | April 19, 2013 | May 16, 2013
Heritage Bank of North Florida | Orange Park | FL | 26680 | FirstAtlantic Bank | April 19, 2013 | May 16, 2013
First Federal Bank | Lexington | KY | 29594 | Your Community Bank | April 19, 2013 | April 23, 2013
| Gold Canyon Bank | Gold Canyon | AZ | 58066 | First Scottsdale Bank, National Association | April 5, 2013 | April 9, 2013
Frontier Bank | LaGrange | GA | 16431 | HeritageBank of the South | March 8, 2013 | March 26, 2013
Covenant Bank | Chicago | IL | 22476 | Liberty Bank and Trust Company | February 15, 2013 | March 4, 2013
1st Regents Bank | Andover | MN | 57157 | First Minnesota Bank | January 18, 2013 | February 28, 2013
Westside Community Bank | University Place | WA | 33997 | Sunwest Bank | January 11, 2013 | January 24, 2013
Community Bank of the Ozarks | Sunrise Beach | MO | 27331 | Bank of Sullivan | December 14, 2012 | January 24, 2013
Hometown Community Bank | Braselton | GA | 57928 | CertusBank, National Association | November 16, 2012 | January 24, 2013
Citizens First National Bank | Princeton | IL | 3731 | Heartland Bank and Trust Company | November 2, 2012 | January 24, 2013
Heritage Bank of Florida | Lutz | FL | 35009 | Centennial Bank | November 2, 2012 | January 24, 2013
NOVA Bank | Berwyn | PA | 27148 | No Acquirer | October 26, 2012 | January 24, 2013
Excel Bank | Sedalia | MO | 19189 | Simmons First National Bank | October 19, 2012 | January 24, 2013
First East Side Savings Bank | Tamarac | FL | 28144 | Stearns Bank N.A. | October 19, 2012 | January 24, 2013
GulfSouth Private Bank | Destin | FL | 58073 | SmartBank | October 19, 2012 | January 24, 2013
First United Bank | Crete | IL | 20685 | Old Plank Trail Community Bank, National Association | September 28, 2012 | November 15, 2012
Truman Bank | St. Louis | MO | 27316 | Simmons First National Bank | September 14, 2012 | December 17, 2012
First Commercial Bank | Bloomington | MN | 35246 | Republic Bank & Trust Company | September 7, 2012 | December 17, 2012
Waukegan Savings Bank | Waukegan | IL | 28243 | First Midwest Bank | August 3, 2012 | October 11, 2012
Jasper Banking Company | Jasper | GA | 16240 | Stearns Bank N.A. | July 27, 2012 | December 17, 2012
Second Federal Savings and Loan Association of Chicago | Chicago | IL | 27986 | Hinsdale Bank & Trust Company | July 20, 2012 | January 14, 2013
Heartland Bank | Leawood | KS | 1361 | Metcalf Bank | July 20, 2012 | December 17, 2012
First Cherokee State Bank | Woodstock | GA | 32711 | Community & Southern Bank | July 20, 2012 | October 31, 2012
Georgia Trust Bank | Buford | GA | 57847 | Community & Southern Bank | July 20, 2012 | December 17, 2012
The Royal Palm Bank of Florida | Naples | FL | 57096 | First National Bank of the Gulf Coast | July 20, 2012 | January 7, 2013
Glasgow Savings Bank | Glasgow | MO | 1056 | Regional Missouri Bank | July 13, 2012 | October 11, 2012
Montgomery Bank & Trust | Ailey | GA | 19498 | Ameris Bank | July 6, 2012 | October 31, 2012
The Farmers Bank of Lynchburg | Lynchburg | TN | 1690 | Clayton Bank and Trust | June 15, 2012 | October 31, 2012
Security Exchange Bank | Marietta | GA | 35299 | Fidelity Bank | June 15, 2012 | October 10, 2012
Putnam State Bank | Palatka | FL | 27405 | Harbor Community Bank | June 15, 2012 | October 10, 2012
Waccamaw Bank | Whiteville | NC | 34515 | First Community Bank | June 8, 2012 | November 8, 2012
Farmers' and Traders' State Bank | Shabbona | IL | 9257 | First State Bank | June 8, 2012 | October 10, 2012
Carolina Federal Savings Bank | Charleston | SC | 35372 | Bank of North Carolina | June 8, 2012 | October 31, 2012
First Capital Bank | Kingfisher | OK | 416 | F & M Bank | June 8, 2012 | October 10, 2012
Alabama Trust Bank, National Association | Sylacauga | AL | 35224 | Southern States Bank | May 18, 2012 | May 20, 2013
Security Bank, National Association | North Lauderdale | FL | 23156 | Banesco USA | May 4, 2012 | October 31, 2012
Palm Desert National Bank | Palm Desert | CA | 23632 | Pacific Premier Bank | April 27, 2012 | May 17, 2013
Plantation Federal Bank | Pawleys Island | SC | 32503 | First Federal Bank | April 27, 2012 | May 17, 2013
Inter Savings Bank, fsb D/B/A InterBank, fsb | Maple Grove | MN | 31495 | Great Southern Bank | April 27, 2012 | May 17, 2013
HarVest Bank of Maryland | Gaithersburg | MD | 57766 | Sonabank | April 27, 2012 | May 17, 2013
Bank of the Eastern Shore | Cambridge | MD | 26759 | No Acquirer | April 27, 2012 | October 17, 2012
Fort Lee Federal Savings Bank, FSB | Fort Lee | NJ | 35527 | Alma Bank | April 20, 2012 | May 17, 2013
Fidelity Bank | Dearborn | MI | 33883 | The Huntington National Bank | March 30, 2012 | May 16, 2013
Premier Bank | Wilmette | IL | 35419 | International Bank of Chicago | March 23, 2012 | October 17, 2012
Covenant Bank & Trust | Rock Spring | GA | 58068 | Stearns Bank, N.A. | March 23, 2012 | October 31, 2012
New City Bank | Chicago | IL | 57597 | No Acquirer | March 9, 2012 | October 29, 2012
Global Commerce Bank | Doraville | GA | 34046 | Metro City Bank | March 2, 2012 | October 31, 2012
Home Savings of America | Little Falls | MN | 29178 | No Acquirer | February 24, 2012 | December 17, 2012
Central Bank of Georgia | Ellaville | GA | 5687 | Ameris Bank | February 24, 2012 | August 9, 2012
SCB Bank | Shelbyville | IN | 29761 | First Merchants Bank, National Association | February 10, 2012 | March 25, 2013
Charter National Bank and Trust | Hoffman Estates | IL | 23187 | Barrington Bank & Trust Company, National Association | February 10, 2012 | March 25, 2013
BankEast | Knoxville | TN | 19869 | U.S.Bank National Association | January 27, 2012 | March 8, 2013
Patriot Bank Minnesota | Forest Lake | MN | 34823 | First Resource Bank | January 27, 2012 | September 12, 2012
Tennessee Commerce Bank | Franklin | TN | 35296 | Republic Bank & Trust Company | January 27, 2012 | November 20, 2012
First Guaranty Bank and Trust Company of Jacksonville | Jacksonville | FL | 16579 | CenterState Bank of Florida, N.A. | January 27, 2012 | September 12, 2012
American Eagle Savings Bank | Boothwyn | PA | 31581 | Capital Bank, N.A. | January 20, 2012 | January 25, 2013
The First State Bank | Stockbridge | GA | 19252 | Hamilton State Bank | January 20, 2012 | January 25, 2013
Central Florida State Bank | Belleview | FL | 57186 | CenterState Bank of Florida, N.A. | January 20, 2012 | January 25, 2013
Western National Bank | Phoenix | AZ | 57917 | Washington Federal | December 16, 2011 | August 13, 2012
Premier Community Bank of the Emerald Coast | Crestview | FL | 58343 | Summit Bank | December 16, 2011 | September 12, 2012
Central Progressive Bank | Lacombe | LA | 19657 | First NBC Bank | November 18, 2011 | August 13, 2012
Polk County Bank | Johnston | IA | 14194 | Grinnell State Bank | November 18, 2011 | August 15, 2012
Community Bank of Rockmart | Rockmart | GA | 57860 | Century Bank of Georgia | November 10, 2011 | August 13, 2012
SunFirst Bank | Saint George | UT | 57087 | Cache Valley Bank | November 4, 2011 | November 16, 2012
Mid City Bank, Inc. | Omaha | NE | 19397 | Premier Bank | November 4, 2011 | August 15, 2012
All American Bank | Des Plaines | IL | 57759 | International Bank of Chicago | October 28, 2011 | August 15, 2012
Community Banks of Colorado | Greenwood Village | CO | 21132 | Bank Midwest, N.A. | October 21, 2011 | January 2, 2013
Community Capital Bank | Jonesboro | GA | 57036 | State Bank and Trust Company | October 21, 2011 | November 8, 2012
Decatur First Bank | Decatur | GA | 34392 | Fidelity Bank | October 21, 2011 | November 8, 2012
Old Harbor Bank | Clearwater | FL | 57537 | 1st United Bank | October 21, 2011 | November 8, 2012
Country Bank | Aledo | IL | 35395 | Blackhawk Bank & Trust | October 14, 2011 | August 15, 2012
First State Bank | Cranford | NJ | 58046 | Northfield Bank | October 14, 2011 | November 8, 2012
Blue Ridge Savings Bank, Inc. | Asheville | NC | 32347 | Bank of North Carolina | October 14, 2011 | November 8, 2012
Piedmont Community Bank | Gray | GA | 57256 | State Bank and Trust Company | October 14, 2011 | January 22, 2013
Sun Security Bank | Ellington | MO | 20115 | Great Southern Bank | October 7, 2011 | November 7, 2012
The RiverBank | Wyoming | MN | 10216 | Central Bank | October 7, 2011 | November 7, 2012
First International Bank | Plano | TX | 33513 | American First National Bank | September 30, 2011 | October 9, 2012
Citizens Bank of Northern California | Nevada City | CA | 33983 | Tri Counties Bank | September 23, 2011 | October 9, 2012
Bank of the Commonwealth | Norfolk | VA | 20408 | Southern Bank and Trust Company | September 23, 2011 | October 9, 2012
The First National Bank of Florida | Milton | FL | 25155 | CharterBank | September 9, 2011 | September 6, 2012
CreekSide Bank | Woodstock | GA | 58226 | Georgia Commerce Bank | September 2, 2011 | September 6, 2012
Patriot Bank of Georgia | Cumming | GA | 58273 | Georgia Commerce Bank | September 2, 2011 | November 2, 2012
First Choice Bank | Geneva | IL | 57212 | Inland Bank & Trust | August 19, 2011 | August 15, 2012
First Southern National Bank | Statesboro | GA | 57239 | Heritage Bank of the South | August 19, 2011 | November 2, 2012
Lydian Private Bank | Palm Beach | FL | 35356 | Sabadell United Bank, N.A. | August 19, 2011 | November 2, 2012
Public Savings Bank | Huntingdon Valley | PA | 34130 | Capital Bank, N.A. | August 18, 2011 | August 15, 2012
The First National Bank of Olathe | Olathe | KS | 4744 | Enterprise Bank & Trust | August 12, 2011 | August 23, 2012
Bank of Whitman | Colfax | WA | 22528 | Columbia State Bank | August 5, 2011 | August 16, 2012
Bank of Shorewood | Shorewood | IL | 22637 | Heartland Bank and Trust Company | August 5, 2011 | August 16, 2012
Integra Bank National Association | Evansville | IN | 4392 | Old National Bank | July 29, 2011 | August 16, 2012
BankMeridian, N.A. | Columbia | SC | 58222 | SCBT National Association | July 29, 2011 | November 2, 2012
Virginia Business Bank | Richmond | VA | 58283 | Xenith Bank | July 29, 2011 | October 9, 2012
Bank of Choice | Greeley | CO | 2994 | Bank Midwest, N.A. | July 22, 2011 | September 12, 2012
LandMark Bank of Florida | Sarasota | FL | 35244 | American Momentum Bank | July 22, 2011 | November 2, 2012
Southshore Community Bank | Apollo Beach | FL | 58056 | American Momentum Bank | July 22, 2011 | November 2, 2012
Summit Bank | Prescott | AZ | 57442 | The Foothills Bank | July 15, 2011 | August 16, 2012
First Peoples Bank | Port St. Lucie | FL | 34870 | Premier American Bank, N.A. | July 15, 2011 | November 2, 2012
High Trust Bank | Stockbridge | GA | 19554 | Ameris Bank | July 15, 2011 | November 2, 2012
One Georgia Bank | Atlanta | GA | 58238 | Ameris Bank | July 15, 2011 | November 2, 2012
Signature Bank | Windsor | CO | 57835 | Points West Community Bank | July 8, 2011 | October 26, 2012
Colorado Capital Bank | Castle Rock | CO | 34522 | First-Citizens Bank & Trust Company | July 8, 2011 | January 15, 2013
First Chicago Bank & Trust | Chicago | IL | 27935 | Northbrook Bank & Trust Company | July 8, 2011 | September 9, 2012
Mountain Heritage Bank | Clayton | GA | 57593 | First American Bank and Trust Company | June 24, 2011 | November 2, 2012
First Commercial Bank of Tampa Bay | Tampa | FL | 27583 | Stonegate Bank | June 17, 2011 | November 2, 2012
McIntosh State Bank | Jackson | GA | 19237 | Hamilton State Bank | June 17, 2011 | November 2, 2012
Atlantic Bank and Trust | Charleston | SC | 58420 | First Citizens Bank and Trust Company, Inc. | June 3, 2011 | October 31, 2012
First Heritage Bank | Snohomish | WA | 23626 | Columbia State Bank | May 27, 2011 | January 28, 2013
Summit Bank | Burlington | WA | 513 | Columbia State Bank | May 20, 2011 | January 22, 2013
First Georgia Banking Company | Franklin | GA | 57647 | CertusBank, National Association | May 20, 2011 | November 13, 2012
Atlantic Southern Bank | Macon | GA | 57213 | CertusBank, National Association | May 20, 2011 | October 31, 2012
Coastal Bank | Cocoa Beach | FL | 34898 | Florida Community Bank, a division of Premier American Bank, N.A. | May 6, 2011 | November 30, 2012
Community Central Bank | Mount Clemens | MI | 34234 | Talmer Bank & Trust | April 29, 2011 | August 16, 2012
The Park Avenue Bank | Valdosta | GA | 19797 | Bank of the Ozarks | April 29, 2011 | November 30, 2012
First Choice Community Bank | Dallas | GA | 58539 | Bank of the Ozarks | April 29, 2011 | January 22, 2013
Cortez Community Bank | Brooksville | FL | 57625 | Florida Community Bank, a division of Premier American Bank, N.A. | April 29, 2011 | November 30, 2012
First National Bank of Central Florida | Winter Park | FL | 26297 | Florida Community Bank, a division of Premier American Bank, N.A. | April 29, 2011 | November 30, 2012
Heritage Banking Group | Carthage | MS | 14273 | Trustmark National Bank | April 15, 2011 | November 30, 2012
Rosemount National Bank | Rosemount | MN | 24099 | Central Bank | April 15, 2011 | August 16, 2012
Superior Bank | Birmingham | AL | 17750 | Superior Bank, National Association | April 15, 2011 | November 30, 2012
Nexity Bank | Birmingham | AL | 19794 | AloStar Bank of Commerce | April 15, 2011 | September 4, 2012
New Horizons Bank | East Ellijay | GA | 57705 | Citizens South Bank | April 15, 2011 | August 16, 2012
Bartow County Bank | Cartersville | GA | 21495 | Hamilton State Bank | April 15, 2011 | January 22, 2013
Nevada Commerce Bank | Las Vegas | NV | 35418 | City National Bank | April 8, 2011 | September 9, 2012
Western Springs National Bank and Trust | Western Springs | IL | 10086 | Heartland Bank and Trust Company | April 8, 2011 | January 22, 2013
The Bank of Commerce | Wood Dale | IL | 34292 | Advantage National Bank Group | March 25, 2011 | January 22, 2013
Legacy Bank | Milwaukee | WI | 34818 | Seaway Bank and Trust Company | March 11, 2011 | September 12, 2012
First National Bank of Davis | Davis | OK | 4077 | The Pauls Valley National Bank | March 11, 2011 | August 20, 2012
Valley Community Bank | St. Charles | IL | 34187 | First State Bank | February 25, 2011 | September 12, 2012
San Luis Trust Bank, FSB | San Luis Obispo | CA | 34783 | First California Bank | February 18, 2011 | August 20, 2012
Charter Oak Bank | Napa | CA | 57855 | Bank of Marin | February 18, 2011 | September 12, 2012
Citizens Bank of Effingham | Springfield | GA | 34601 | Heritage Bank of the South | February 18, 2011 | November 2, 2012
Habersham Bank | Clarkesville | GA | 151 | SCBT National Association | February 18, 2011 | November 2, 2012
Canyon National Bank | Palm Springs | CA | 34692 | Pacific Premier Bank | February 11, 2011 | September 12, 2012
Badger State Bank | Cassville | WI | 13272 | Royal Bank | February 11, 2011 | September 12, 2012
Peoples State Bank | Hamtramck | MI | 14939 | First Michigan Bank | February 11, 2011 | January 22, 2013
Sunshine State Community Bank | Port Orange | FL | 35478 | Premier American Bank, N.A. | February 11, 2011 | November 2, 2012
Community First Bank Chicago | Chicago | IL | 57948 | Northbrook Bank & Trust Company | February 4, 2011 | August 20, 2012
North Georgia Bank | Watkinsville | GA | 35242 | BankSouth | February 4, 2011 | November 2, 2012
American Trust Bank | Roswell | GA | 57432 | Renasant Bank | February 4, 2011 | October 31, 2012
First Community Bank | Taos | NM | 12261 | U.S. Bank, N.A. | January 28, 2011 | September 12, 2012
FirsTier Bank | Louisville | CO | 57646 | No Acquirer | January 28, 2011 | September 12, 2012
Evergreen State Bank | Stoughton | WI | 5328 | McFarland State Bank | January 28, 2011 | September 12, 2012
The First State Bank | Camargo | OK | 2303 | Bank 7 | January 28, 2011 | September 12, 2012
United Western Bank | Denver | CO | 31293 | First-Citizens Bank & Trust Company | January 21, 2011 | September 12, 2012
The Bank of Asheville | Asheville | NC | 34516 | First Bank | January 21, 2011 | November 2, 2012
CommunitySouth Bank & Trust | Easley | SC | 57868 | CertusBank, National Association | January 21, 2011 | November 2, 2012
Enterprise Banking Company | McDonough | GA | 19758 | No Acquirer | January 21, 2011 | November 2, 2012
Oglethorpe Bank | Brunswick | GA | 57440 | Bank of the Ozarks | January 14, 2011 | November 2, 2012
Legacy Bank | Scottsdale | AZ | 57820 | Enterprise Bank & Trust | January 7, 2011 | September 12, 2012
First Commercial Bank of Florida | Orlando | FL | 34965 | First Southern Bank | January 7, 2011 | November 2, 2012
Community National Bank | Lino Lakes | MN | 23306 | Farmers & Merchants Savings Bank | December 17, 2010 | August 20, 2012
First Southern Bank | Batesville | AR | 58052 | Southern Bank | December 17, 2010 | August 20, 2012
United Americas Bank, N.A. | Atlanta | GA | 35065 | State Bank and Trust Company | December 17, 2010 | November 2, 2012
Appalachian Community Bank, FSB | McCaysville | GA | 58495 | Peoples Bank of East Tennessee | December 17, 2010 | October 31, 2012
Chestatee State Bank | Dawsonville | GA | 34578 | Bank of the Ozarks | December 17, 2010 | November 2, 2012
The Bank of Miami,N.A. | Coral Gables | FL | 19040 | 1st United Bank | December 17, 2010 | November 2, 2012
Earthstar Bank | Southampton | PA | 35561 | Polonia Bank | December 10, 2010 | August 20, 2012
Paramount Bank | Farmington Hills | MI | 34673 | Level One Bank | December 10, 2010 | August 20, 2012
First Banking Center | Burlington | WI | 5287 | First Michigan Bank | November 19, 2010 | August 20, 2012
Allegiance Bank of North America | Bala Cynwyd | PA | 35078 | VIST Bank | November 19, 2010 | August 20, 2012
Gulf State Community Bank | Carrabelle | FL | 20340 | Centennial Bank | November 19, 2010 | November 2, 2012
Copper Star Bank | Scottsdale | AZ | 35463 | Stearns Bank, N.A. | November 12, 2010 | August 20, 2012
Darby Bank & Trust Co. | Vidalia | GA | 14580 | Ameris Bank | November 12, 2010 | January 15, 2013
Tifton Banking Company | Tifton | GA | 57831 | Ameris Bank | November 12, 2010 | November 2, 2012
First Vietnamese American Bank In Vietnamese | Westminster | CA | 57885 | Grandpoint Bank | November 5, 2010 | September 12, 2012
Pierce Commercial Bank | Tacoma | WA | 34411 | Heritage Bank | November 5, 2010 | August 20, 2012
Western Commercial Bank | Woodland Hills | CA | 58087 | First California Bank | November 5, 2010 | September 12, 2012
K Bank | Randallstown | MD | 31263 | Manufacturers and Traders Trust Company (M&T Bank) | November 5, 2010 | August 20, 2012
First Arizona Savings, A FSB | Scottsdale | AZ | 32582 | No Acquirer | October 22, 2010 | August 20, 2012
Hillcrest Bank | Overland Park | KS | 22173 | Hillcrest Bank, N.A. | October 22, 2010 | August 20, 2012
First Suburban National Bank | Maywood | IL | 16089 | Seaway Bank and Trust Company | October 22, 2010 | August 20, 2012
The First National Bank of Barnesville | Barnesville | GA | 2119 | United Bank | October 22, 2010 | November 2, 2012
The Gordon Bank | Gordon | GA | 33904 | Morris Bank | October 22, 2010 | November 2, 2012
Progress Bank of Florida | Tampa | FL | 32251 | Bay Cities Bank | October 22, 2010 | November 2, 2012
First Bank of Jacksonville | Jacksonville | FL | 27573 | Ameris Bank | October 22, 2010 | November 2, 2012
Premier Bank | Jefferson City | MO | 34016 | Providence Bank | October 15, 2010 | August 20, 2012
WestBridge Bank and Trust Company | Chesterfield | MO | 58205 | Midland States Bank | October 15, 2010 | August 20, 2012
Security Savings Bank, F.S.B. | Olathe | KS | 30898 | Simmons First National Bank | October 15, 2010 | August 20, 2012
Shoreline Bank | Shoreline | WA | 35250 | GBC International Bank | October 1, 2010 | August 20, 2012
Wakulla Bank | Crawfordville | FL | 21777 | Centennial Bank | October 1, 2010 | November 2, 2012
North County Bank | Arlington | WA | 35053 | Whidbey Island Bank | September 24, 2010 | August 20, 2012
Haven Trust Bank Florida | Ponte Vedra Beach | FL | 58308 | First Southern Bank | September 24, 2010 | November 5, 2012
Maritime Savings Bank | West Allis | WI | 28612 | North Shore Bank, FSB | September 17, 2010 | August 20, 2012
Bramble Savings Bank | Milford | OH | 27808 | Foundation Bank | September 17, 2010 | August 20, 2012
The Peoples Bank | Winder | GA | 182 | Community & Southern Bank | September 17, 2010 | November 5, 2012
First Commerce Community Bank | Douglasville | GA | 57448 | Community & Southern Bank | September 17, 2010 | January 15, 2013
Bank of Ellijay | Ellijay | GA | 58197 | Community & Southern Bank | September 17, 2010 | January 15, 2013
ISN Bank | Cherry Hill | NJ | 57107 | Customers Bank | September 17, 2010 | August 22, 2012
Horizon Bank | Bradenton | FL | 35061 | Bank of the Ozarks | September 10, 2010 | November 5, 2012
Sonoma Valley Bank | Sonoma | CA | 27259 | Westamerica Bank | August 20, 2010 | September 12, 2012
Los Padres Bank | Solvang | CA | 32165 | Pacific Western Bank | August 20, 2010 | September 12, 2012
Butte Community Bank | Chico | CA | 33219 | Rabobank, N.A. | August 20, 2010 | September 12, 2012
Pacific State Bank | Stockton | CA | 27090 | Rabobank, N.A. | August 20, 2010 | September 12, 2012
ShoreBank | Chicago | IL | 15640 | Urban Partnership Bank | August 20, 2010 | May 16, 2013
Imperial Savings and Loan Association | Martinsville | VA | 31623 | River Community Bank, N.A. | August 20, 2010 | August 24, 2012
Independent National Bank | Ocala | FL | 27344 | CenterState Bank of Florida, N.A. | August 20, 2010 | November 5, 2012
Community National Bank at Bartow | Bartow | FL | 25266 | CenterState Bank of Florida, N.A. | August 20, 2010 | November 5, 2012
Palos Bank and Trust Company | Palos Heights | IL | 17599 | First Midwest Bank | August 13, 2010 | August 22, 2012
Ravenswood Bank | Chicago | IL | 34231 | Northbrook Bank & Trust Company | August 6, 2010 | August 22, 2012
LibertyBank | Eugene | OR | 31964 | Home Federal Bank | July 30, 2010 | August 22, 2012
The Cowlitz Bank | Longview | WA | 22643 | Heritage Bank | July 30, 2010 | August 22, 2012
Coastal Community Bank | Panama City Beach | FL | 9619 | Centennial Bank | July 30, 2010 | November 5, 2012
Bayside Savings Bank | Port Saint Joe | FL | 57669 | Centennial Bank | July 30, 2010 | November 5, 2012
Northwest Bank & Trust | Acworth | GA | 57658 | State Bank and Trust Company | July 30, 2010 | November 5, 2012
Home Valley Bank | Cave Junction | OR | 23181 | South Valley Bank & Trust | July 23, 2010 | September 12, 2012
SouthwestUSA Bank | Las Vegas | NV | 35434 | Plaza Bank | July 23, 2010 | August 22, 2012
Community Security Bank | New Prague | MN | 34486 | Roundbank | July 23, 2010 | September 12, 2012
Thunder Bank | Sylvan Grove | KS | 10506 | The Bennington State Bank | July 23, 2010 | September 13, 2012
Williamsburg First National Bank | Kingstree | SC | 17837 | First Citizens Bank and Trust Company, Inc. | July 23, 2010 | November 5, 2012
Crescent Bank and Trust Company | Jasper | GA | 27559 | Renasant Bank | July 23, 2010 | November 5, 2012
Sterling Bank | Lantana | FL | 32536 | IBERIABANK | July 23, 2010 | November 5, 2012
Mainstreet Savings Bank, FSB | Hastings | MI | 28136 | Commercial Bank | July 16, 2010 | September 13, 2012
Olde Cypress Community Bank | Clewiston | FL | 28864 | CenterState Bank of Florida, N.A. | July 16, 2010 | November 5, 2012
Turnberry Bank | Aventura | FL | 32280 | NAFH National Bank | July 16, 2010 | November 5, 2012
Metro Bank of Dade County | Miami | FL | 25172 | NAFH National Bank | July 16, 2010 | November 5, 2012
First National Bank of the South | Spartanburg | SC | 35383 | NAFH National Bank | July 16, 2010 | November 5, 2012
Woodlands Bank | Bluffton | SC | 32571 | Bank of the Ozarks | July 16, 2010 | November 5, 2012
Home National Bank | Blackwell | OK | 11636 | RCB Bank | July 9, 2010 | December 10, 2012
USA Bank | Port Chester | NY | 58072 | New Century Bank | July 9, 2010 | September 14, 2012
Ideal Federal Savings Bank | Baltimore | MD | 32456 | No Acquirer | July 9, 2010 | September 14, 2012
Bay National Bank | Baltimore | MD | 35462 | Bay Bank, FSB | July 9, 2010 | January 15, 2013
High Desert State Bank | Albuquerque | NM | 35279 | First American Bank | June 25, 2010 | September 14, 2012
First National Bank | Savannah | GA | 34152 | The Savannah Bank, N.A. | June 25, 2010 | November 5, 2012
Peninsula Bank | Englewood | FL | 26563 | Premier American Bank, N.A. | June 25, 2010 | November 5, 2012
Nevada Security Bank | Reno | NV | 57110 | Umpqua Bank | June 18, 2010 | August 23, 2012
Washington First International Bank | Seattle | WA | 32955 | East West Bank | June 11, 2010 | September 14, 2012
TierOne Bank | Lincoln | NE | 29341 | Great Western Bank | June 4, 2010 | September 14, 2012
Arcola Homestead Savings Bank | Arcola | IL | 31813 | No Acquirer | June 4, 2010 | September 14, 2012
First National Bank | Rosedale | MS | 15814 | The Jefferson Bank | June 4, 2010 | November 5, 2012
Sun West Bank | Las Vegas | NV | 34785 | City National Bank | May 28, 2010 | September 14, 2012
Granite Community Bank, NA | Granite Bay | CA | 57315 | Tri Counties Bank | May 28, 2010 | September 14, 2012
Bank of Florida - Tampa | Tampa | FL | 57814 | EverBank | May 28, 2010 | November 5, 2012
Bank of Florida - Southwest | Naples | FL | 35106 | EverBank | May 28, 2010 | November 5, 2012
Bank of Florida - Southeast | Fort Lauderdale | FL | 57360 | EverBank | May 28, 2010 | November 5, 2012
Pinehurst Bank | Saint Paul | MN | 57735 | Coulee Bank | May 21, 2010 | October 26, 2012
Midwest Bank and Trust Company | Elmwood Park | IL | 18117 | FirstMerit Bank, N.A. | May 14, 2010 | August 23, 2012
Southwest Community Bank | Springfield | MO | 34255 | Simmons First National Bank | May 14, 2010 | August 23, 2012
New Liberty Bank | Plymouth | MI | 35586 | Bank of Ann Arbor | May 14, 2010 | August 23, 2012
Satilla Community Bank | Saint Marys | GA | 35114 | Ameris Bank | May 14, 2010 | November 5, 2012
1st Pacific Bank of California | San Diego | CA | 35517 | City National Bank | May 7, 2010 | December 13, 2012
Towne Bank of Arizona | Mesa | AZ | 57697 | Commerce Bank of Arizona | May 7, 2010 | August 23, 2012
Access Bank | Champlin | MN | 16476 | PrinsBank | May 7, 2010 | August 23, 2012
The Bank of Bonifay | Bonifay | FL | 14246 | First Federal Bank of Florida | May 7, 2010 | November 5, 2012
Frontier Bank | Everett | WA | 22710 | Union Bank, N.A. | April 30, 2010 | January 15, 2013
BC National Banks | Butler | MO | 17792 | Community First Bank | April 30, 2010 | August 23, 2012
Champion Bank | Creve Coeur | MO | 58362 | BankLiberty | April 30, 2010 | August 23, 2012
CF Bancorp | Port Huron | MI | 30005 | First Michigan Bank | April 30, 2010 | January 15, 2013
Westernbank Puerto Rico En Espanol | Mayaguez | PR | 31027 | Banco Popular de Puerto Rico | April 30, 2010 | November 5, 2012
R-G Premier Bank of Puerto Rico En Espanol | Hato Rey | PR | 32185 | Scotiabank de Puerto Rico | April 30, 2010 | November 5, 2012
Eurobank En Espanol | San Juan | PR | 27150 | Oriental Bank and Trust | April 30, 2010 | November 5, 2012
Wheatland Bank | Naperville | IL | 58429 | Wheaton Bank & Trust | April 23, 2010 | August 23, 2012
Peotone Bank and Trust Company | Peotone | IL | 10888 | First Midwest Bank | April 23, 2010 | August 23, 2012
Lincoln Park Savings Bank | Chicago | IL | 30600 | Northbrook Bank & Trust Company | April 23, 2010 | August 23, 2012
New Century Bank | Chicago | IL | 34821 | MB Financial Bank, N.A. | April 23, 2010 | August 23, 2012
Citizens Bank and Trust Company of Chicago | Chicago | IL | 34658 | Republic Bank of Chicago | April 23, 2010 | August 23, 2012
Broadway Bank | Chicago | IL | 22853 | MB Financial Bank, N.A. | April 23, 2010 | August 23, 2012
Amcore Bank, National Association | Rockford | IL | 3735 | Harris N.A. | April 23, 2010 | August 23, 2012
City Bank | Lynnwood | WA | 21521 | Whidbey Island Bank | April 16, 2010 | September 14, 2012
Tamalpais Bank | San Rafael | CA | 33493 | Union Bank, N.A. | April 16, 2010 | August 23, 2012
Innovative Bank | Oakland | CA | 23876 | Center Bank | April 16, 2010 | August 23, 2012
Butler Bank | Lowell | MA | 26619 | People's United Bank | April 16, 2010 | August 23, 2012
Riverside National Bank of Florida | Fort Pierce | FL | 24067 | TD Bank, N.A. | April 16, 2010 | November 5, 2012
AmericanFirst Bank | Clermont | FL | 57724 | TD Bank, N.A. | April 16, 2010 | October 31, 2012
First Federal Bank of North Florida | Palatka | FL | 28886 | TD Bank, N.A. | April 16, 2010 | January 15, 2013
Lakeside Community Bank | Sterling Heights | MI | 34878 | No Acquirer | April 16, 2010 | August 23, 2012
Beach First National Bank | Myrtle Beach | SC | 34242 | Bank of North Carolina | April 9, 2010 | November 5, 2012
Desert Hills Bank | Phoenix | AZ | 57060 | New York Community Bank | March 26, 2010 | August 23, 2012
Unity National Bank | Cartersville | GA | 34678 | Bank of the Ozarks | March 26, 2010 | September 14, 2012
Key West Bank | Key West | FL | 34684 | Centennial Bank | March 26, 2010 | August 23, 2012
McIntosh Commercial Bank | Carrollton | GA | 57399 | CharterBank | March 26, 2010 | August 23, 2012
State Bank of Aurora | Aurora | MN | 8221 | Northern State Bank | March 19, 2010 | August 23, 2012
First Lowndes Bank | Fort Deposit | AL | 24957 | First Citizens Bank | March 19, 2010 | August 23, 2012
Bank of Hiawassee | Hiawassee | GA | 10054 | Citizens South Bank | March 19, 2010 | August 23, 2012
Appalachian Community Bank | Ellijay | GA | 33989 | Community & Southern Bank | March 19, 2010 | October 31, 2012
Advanta Bank Corp. | Draper | UT | 33535 | No Acquirer | March 19, 2010 | September 14, 2012
Century Security Bank | Duluth | GA | 58104 | Bank of Upson | March 19, 2010 | August 23, 2012
American National Bank | Parma | OH | 18806 | The National Bank and Trust Company | March 19, 2010 | August 23, 2012
Statewide Bank | Covington | LA | 29561 | Home Bank | March 12, 2010 | August 23, 2012
Old Southern Bank | Orlando | FL | 58182 | Centennial Bank | March 12, 2010 | August 23, 2012
The Park Avenue Bank | New York | NY | 27096 | Valley National Bank | March 12, 2010 | August 23, 2012
LibertyPointe Bank | New York | NY | 58071 | Valley National Bank | March 11, 2010 | August 23, 2012
Centennial Bank | Ogden | UT | 34430 | No Acquirer | March 5, 2010 | September 14, 2012
Waterfield Bank | Germantown | MD | 34976 | No Acquirer | March 5, 2010 | August 23, 2012
Bank of Illinois | Normal | IL | 9268 | Heartland Bank and Trust Company | March 5, 2010 | August 23, 2012
Sun American Bank | Boca Raton | FL | 27126 | First-Citizens Bank & Trust Company | March 5, 2010 | August 23, 2012
Rainier Pacific Bank | Tacoma | WA | 38129 | Umpqua Bank | February 26, 2010 | August 23, 2012
Carson River Community Bank | Carson City | NV | 58352 | Heritage Bank of Nevada | February 26, 2010 | January 15, 2013
La Jolla Bank, FSB | La Jolla | CA | 32423 | OneWest Bank, FSB | February 19, 2010 | August 24, 2012
George Washington Savings Bank | Orland Park | IL | 29952 | FirstMerit Bank, N.A. | February 19, 2010 | August 24, 2012
The La Coste National Bank | La Coste | TX | 3287 | Community National Bank | February 19, 2010 | September 14, 2012
Marco Community Bank | Marco Island | FL | 57586 | Mutual of Omaha Bank | February 19, 2010 | August 24, 2012
1st American State Bank of Minnesota | Hancock | MN | 15448 | Community Development Bank, FSB | February 5, 2010 | August 24, 2012
American Marine Bank | Bainbridge Island | WA | 16730 | Columbia State Bank | January 29, 2010 | August 24, 2012
First Regional Bank | Los Angeles | CA | 23011 | First-Citizens Bank & Trust Company | January 29, 2010 | August 24, 2012
Community Bank and Trust | Cornelia | GA | 5702 | SCBT National Association | January 29, 2010 | January 15, 2013
Marshall Bank, N.A. | Hallock | MN | 16133 | United Valley Bank | January 29, 2010 | August 23, 2012
Florida Community Bank | Immokalee | FL | 5672 | Premier American Bank, N.A. | January 29, 2010 | January 15, 2013
First National Bank of Georgia | Carrollton | GA | 16480 | Community & Southern Bank | January 29, 2010 | December 13, 2012
Columbia River Bank | The Dalles | OR | 22469 | Columbia State Bank | January 22, 2010 | September 14, 2012
Evergreen Bank | Seattle | WA | 20501 | Umpqua Bank | January 22, 2010 | January 15, 2013
Charter Bank | Santa Fe | NM | 32498 | Charter Bank | January 22, 2010 | August 23, 2012
Bank of Leeton | Leeton | MO | 8265 | Sunflower Bank, N.A. | January 22, 2010 | January 15, 2013
Premier American Bank | Miami | FL | 57147 | Premier American Bank, N.A. | January 22, 2010 | December 13, 2012
Barnes Banking Company | Kaysville | UT | 1252 | No Acquirer | January 15, 2010 | August 23, 2012
St. Stephen State Bank | St. Stephen | MN | 17522 | First State Bank of St. Joseph | January 15, 2010 | August 23, 2012
Town Community Bank & Trust | Antioch | IL | 34705 | First American Bank | January 15, 2010 | August 23, 2012
Horizon Bank | Bellingham | WA | 22977 | Washington Federal Savings and Loan Association | January 8, 2010 | August 23, 2012
First Federal Bank of California, F.S.B. | Santa Monica | CA | 28536 | OneWest Bank, FSB | December 18, 2009 | August 23, 2012
Imperial Capital Bank | La Jolla | CA | 26348 | City National Bank | December 18, 2009 | September 5, 2012
Independent Bankers' Bank | Springfield | IL | 26820 | The Independent BankersBank (TIB) | December 18, 2009 | August 23, 2012
New South Federal Savings Bank | Irondale | AL | 32276 | Beal Bank | December 18, 2009 | August 23, 2012
Citizens State Bank | New Baltimore | MI | 1006 | No Acquirer | December 18, 2009 | November 5, 2012
Peoples First Community Bank | Panama City | FL | 32167 | Hancock Bank | December 18, 2009 | November 5, 2012
RockBridge Commercial Bank | Atlanta | GA | 58315 | No Acquirer | December 18, 2009 | November 5, 2012
SolutionsBank | Overland Park | KS | 4731 | Arvest Bank | December 11, 2009 | August 23, 2012
Valley Capital Bank, N.A. | Mesa | AZ | 58399 | Enterprise Bank & Trust | December 11, 2009 | August 23, 2012
Republic Federal Bank, N.A. | Miami | FL | 22846 | 1st United Bank | December 11, 2009 | November 5, 2012
Greater Atlantic Bank | Reston | VA | 32583 | Sonabank | December 4, 2009 | November 5, 2012
Benchmark Bank | Aurora | IL | 10440 | MB Financial Bank, N.A. | December 4, 2009 | August 23, 2012
AmTrust Bank | Cleveland | OH | 29776 | New York Community Bank | December 4, 2009 | November 5, 2012
The Tattnall Bank | Reidsville | GA | 12080 | Heritage Bank of the South | December 4, 2009 | November 5, 2012
First Security National Bank | Norcross | GA | 26290 | State Bank and Trust Company | December 4, 2009 | November 5, 2012
The Buckhead Community Bank | Atlanta | GA | 34663 | State Bank and Trust Company | December 4, 2009 | November 5, 2012
Commerce Bank of Southwest Florida | Fort Myers | FL | 58016 | Central Bank | November 20, 2009 | November 5, 2012
Pacific Coast National Bank | San Clemente | CA | 57914 | Sunwest Bank | November 13, 2009 | August 22, 2012
Orion Bank | Naples | FL | 22427 | IBERIABANK | November 13, 2009 | November 5, 2012
Century Bank, F.S.B. | Sarasota | FL | 32267 | IBERIABANK | November 13, 2009 | August 22, 2012
United Commercial Bank | San Francisco | CA | 32469 | East West Bank | November 6, 2009 | November 5, 2012
Gateway Bank of St. Louis | St. Louis | MO | 19450 | Central Bank of Kansas City | November 6, 2009 | August 22, 2012
Prosperan Bank | Oakdale | MN | 35074 | Alerus Financial, N.A. | November 6, 2009 | August 22, 2012
Home Federal Savings Bank | Detroit | MI | 30329 | Liberty Bank and Trust Company | November 6, 2009 | August 22, 2012
United Security Bank | Sparta | GA | 22286 | Ameris Bank | November 6, 2009 | January 15, 2013
North Houston Bank | Houston | TX | 18776 | U.S. Bank N.A. | October 30, 2009 | August 22, 2012
Madisonville State Bank | Madisonville | TX | 33782 | U.S. Bank N.A. | October 30, 2009 | August 22, 2012
Citizens National Bank | Teague | TX | 25222 | U.S. Bank N.A. | October 30, 2009 | August 22, 2012
Park National Bank | Chicago | IL | 11677 | U.S. Bank N.A. | October 30, 2009 | August 22, 2012
Pacific National Bank | San Francisco | CA | 30006 | U.S. Bank N.A. | October 30, 2009 | August 22, 2012
California National Bank | Los Angeles | CA | 34659 | U.S. Bank N.A. | October 30, 2009 | September 5, 2012
San Diego National Bank | San Diego | CA | 23594 | U.S. Bank N.A. | October 30, 2009 | August 22, 2012
Community Bank of Lemont | Lemont | IL | 35291 | U.S. Bank N.A. | October 30, 2009 | January 15, 2013
Bank USA, N.A. | Phoenix | AZ | 32218 | U.S. Bank N.A. | October 30, 2009 | August 22, 2012
First DuPage Bank | Westmont | IL | 35038 | First Midwest Bank | October 23, 2009 | August 22, 2012
Riverview Community Bank | Otsego | MN | 57525 | Central Bank | October 23, 2009 | August 22, 2012
Bank of Elmwood | Racine | WI | 18321 | Tri City National Bank | October 23, 2009 | August 22, 2012
Flagship National Bank | Bradenton | FL | 35044 | First Federal Bank of Florida | October 23, 2009 | August 22, 2012
Hillcrest Bank Florida | Naples | FL | 58336 | Stonegate Bank | October 23, 2009 | August 22, 2012
American United Bank | Lawrenceville | GA | 57794 | Ameris Bank | October 23, 2009 | September 5, 2012
Partners Bank | Naples | FL | 57959 | Stonegate Bank | October 23, 2009 | January 15, 2013
San Joaquin Bank | Bakersfield | CA | 23266 | Citizens Business Bank | October 16, 2009 | August 22, 2012
Southern Colorado National Bank | Pueblo | CO | 57263 | Legacy Bank | October 2, 2009 | September 5, 2012
Jennings State Bank | Spring Grove | MN | 11416 | Central Bank | October 2, 2009 | August 21, 2012
Warren Bank | Warren | MI | 34824 | The Huntington National Bank | October 2, 2009 | August 21, 2012
Georgian Bank | Atlanta | GA | 57151 | First Citizens Bank and Trust Company, Inc. | September 25, 2009 | August 21, 2012
Irwin Union Bank, F.S.B. | Louisville | KY | 57068 | First Financial Bank, N.A. | September 18, 2009 | September 5, 2012
Irwin Union Bank and Trust Company | Columbus | IN | 10100 | First Financial Bank, N.A. | September 18, 2009 | August 21, 2012
Venture Bank | Lacey | WA | 22868 | First-Citizens Bank & Trust Company | September 11, 2009 | August 21, 2012
Brickwell Community Bank | Woodbury | MN | 57736 | CorTrust Bank N.A. | September 11, 2009 | January 15, 2013
Corus Bank, N.A. | Chicago | IL | 13693 | MB Financial Bank, N.A. | September 11, 2009 | August 21, 2012
First State Bank | Flagstaff | AZ | 34875 | Sunwest Bank | September 4, 2009 | January 15, 2013
Platinum Community Bank | Rolling Meadows | IL | 35030 | No Acquirer | September 4, 2009 | August 21, 2012
Vantus Bank | Sioux City | IN | 27732 | Great Southern Bank | September 4, 2009 | August 21, 2012
InBank | Oak Forest | IL | 20203 | MB Financial Bank, N.A. | September 4, 2009 | August 21, 2012
First Bank of Kansas City | Kansas City | MO | 25231 | Great American Bank | September 4, 2009 | August 21, 2012
Affinity Bank | Ventura | CA | 27197 | Pacific Western Bank | August 28, 2009 | August 21, 2012
Mainstreet Bank | Forest Lake | MN | 1909 | Central Bank | August 28, 2009 | August 21, 2012
Bradford Bank | Baltimore | MD | 28312 | Manufacturers and Traders Trust Company (M&T Bank) | August 28, 2009 | January 15, 2013
Guaranty Bank | Austin | TX | 32618 | BBVA Compass | August 21, 2009 | August 21, 2012
CapitalSouth Bank | Birmingham | AL | 22130 | IBERIABANK | August 21, 2009 | January 15, 2013
First Coweta Bank | Newnan | GA | 57702 | United Bank | August 21, 2009 | January 15, 2013
ebank | Atlanta | GA | 34682 | Stearns Bank, N.A. | August 21, 2009 | August 21, 2012
Community Bank of Nevada | Las Vegas | NV | 34043 | No Acquirer | August 14, 2009 | August 21, 2012
Community Bank of Arizona | Phoenix | AZ | 57645 | MidFirst Bank | August 14, 2009 | August 21, 2012
Union Bank, National Association | Gilbert | AZ | 34485 | MidFirst Bank | August 14, 2009 | August 21, 2012
Colonial Bank | Montgomery | AL | 9609 | Branch Banking & Trust Company, (BB&T) | August 14, 2009 | September 5, 2012
Dwelling House Savings and Loan Association | Pittsburgh | PA | 31559 | PNC Bank, N.A. | August 14, 2009 | January 15, 2013
Community First Bank | Prineville | OR | 23268 | Home Federal Bank | August 7, 2009 | January 15, 2013
Community National Bank of Sarasota County | Venice | FL | 27183 | Stearns Bank, N.A. | August 7, 2009 | August 20, 2012
First State Bank | Sarasota | FL | 27364 | Stearns Bank, N.A. | August 7, 2009 | August 20, 2012
Mutual Bank | Harvey | IL | 18659 | United Central Bank | July 31, 2009 | August 20, 2012
First BankAmericano | Elizabeth | NJ | 34270 | Crown Bank | July 31, 2009 | August 20, 2012
Peoples Community Bank | West Chester | OH | 32288 | First Financial Bank, N.A. | July 31, 2009 | August 20, 2012
Integrity Bank | Jupiter | FL | 57604 | Stonegate Bank | July 31, 2009 | August 20, 2012
First State Bank of Altus | Altus | OK | 9873 | Herring Bank | July 31, 2009 | August 20, 2012
Security Bank of Jones County | Gray | GA | 8486 | State Bank and Trust Company | July 24, 2009 | August 20, 2012
Security Bank of Houston County | Perry | GA | 27048 | State Bank and Trust Company | July 24, 2009 | August 20, 2012
Security Bank of Bibb County | Macon | GA | 27367 | State Bank and Trust Company | July 24, 2009 | August 20, 2012
Security Bank of North Metro | Woodstock | GA | 57105 | State Bank and Trust Company | July 24, 2009 | August 20, 2012
Security Bank of North Fulton | Alpharetta | GA | 57430 | State Bank and Trust Company | July 24, 2009 | August 20, 2012
Security Bank of Gwinnett County | Suwanee | GA | 57346 | State Bank and Trust Company | July 24, 2009 | August 20, 2012
Waterford Village Bank | Williamsville | NY | 58065 | Evans Bank, N.A. | July 24, 2009 | August 20, 2012
Temecula Valley Bank | Temecula | CA | 34341 | First-Citizens Bank & Trust Company | July 17, 2009 | August 20, 2012
Vineyard Bank | Rancho Cucamonga | CA | 23556 | California Bank & Trust | July 17, 2009 | August 20, 2012
BankFirst | Sioux Falls | SD | 34103 | Alerus Financial, N.A. | July 17, 2009 | August 20, 2012
First Piedmont Bank | Winder | GA | 34594 | First American Bank and Trust Company | July 17, 2009 | January 15, 2013
Bank of Wyoming | Thermopolis | WY | 22754 | Central Bank & Trust | July 10, 2009 | August 20, 2012
Founders Bank | Worth | IL | 18390 | The PrivateBank and Trust Company | July 2, 2009 | August 20, 2012
Millennium State Bank of Texas | Dallas | TX | 57667 | State Bank of Texas | July 2, 2009 | October 26, 2012
First National Bank of Danville | Danville | IL | 3644 | First Financial Bank, N.A. | July 2, 2009 | August 20, 2012
Elizabeth State Bank | Elizabeth | IL | 9262 | Galena State Bank and Trust Company | July 2, 2009 | August 20, 2012
Rock River Bank | Oregon | IL | 15302 | The Harvard State Bank | July 2, 2009 | August 20, 2012
First State Bank of Winchester | Winchester | IL | 11710 | The First National Bank of Beardstown | July 2, 2009 | August 20, 2012
John Warner Bank | Clinton | IL | 12093 | State Bank of Lincoln | July 2, 2009 | August 20, 2012
Mirae Bank | Los Angeles | CA | 57332 | Wilshire State Bank | June 26, 2009 | August 20, 2012
MetroPacific Bank | Irvine | CA | 57893 | Sunwest Bank | June 26, 2009 | August 20, 2012
Horizon Bank | Pine City | MN | 9744 | Stearns Bank, N.A. | June 26, 2009 | August 20, 2012
Neighborhood Community Bank | Newnan | GA | 35285 | CharterBank | June 26, 2009 | August 20, 2012
Community Bank of West Georgia | Villa Rica | GA | 57436 | No Acquirer | June 26, 2009 | August 17, 2012
First National Bank of Anthony | Anthony | KS | 4614 | Bank of Kansas | June 19, 2009 | August 17, 2012
Cooperative Bank | Wilmington | NC | 27837 | First Bank | June 19, 2009 | August 17, 2012
Southern Community Bank | Fayetteville | GA | 35251 | United Community Bank | June 19, 2009 | August 17, 2012
Bank of Lincolnwood | Lincolnwood | IL | 17309 | Republic Bank of Chicago | June 5, 2009 | August 17, 2012
Citizens National Bank | Macomb | IL | 5757 | Morton Community Bank | May 22, 2009 | September 4, 2012
Strategic Capital Bank | Champaign | IL | 35175 | Midland States Bank | May 22, 2009 | September 4, 2012
BankUnited, FSB | Coral Gables | FL | 32247 | BankUnited | May 21, 2009 | August 17, 2012
Westsound Bank | Bremerton | WA | 34843 | Kitsap Bank | May 8, 2009 | September 4, 2012
America West Bank | Layton | UT | 35461 | Cache Valley Bank | May 1, 2009 | August 17, 2012
Citizens Community Bank | Ridgewood | NJ | 57563 | North Jersey Community Bank | May 1, 2009 | September 4, 2012
Silverton Bank, NA | Atlanta | GA | 26535 | No Acquirer | May 1, 2009 | August 17, 2012
First Bank of Idaho | Ketchum | ID | 34396 | U.S. Bank, N.A. | April 24, 2009 | August 17, 2012
First Bank of Beverly Hills | Calabasas | CA | 32069 | No Acquirer | April 24, 2009 | September 4, 2012
Michigan Heritage Bank | Farmington Hills | MI | 34369 | Level One Bank | April 24, 2009 | August 17, 2012
American Southern Bank | Kennesaw | GA | 57943 | Bank of North Georgia | April 24, 2009 | August 17, 2012
Great Basin Bank of Nevada | Elko | NV | 33824 | Nevada State Bank | April 17, 2009 | September 4, 2012
American Sterling Bank | Sugar Creek | MO | 8266 | Metcalf Bank | April 17, 2009 | August 31, 2012
New Frontier Bank | Greeley | CO | 34881 | No Acquirer | April 10, 2009 | September 4, 2012
Cape Fear Bank | Wilmington | NC | 34639 | First Federal Savings and Loan Association | April 10, 2009 | August 17, 2012
Omni National Bank | Atlanta | GA | 22238 | No Acquirer | March 27, 2009 | August 17, 2012
TeamBank, NA | Paola | KS | 4754 | Great Southern Bank | March 20, 2009 | August 17, 2012
Colorado National Bank | Colorado Springs | CO | 18896 | Herring Bank | March 20, 2009 | August 17, 2012
FirstCity Bank | Stockbridge | GA | 18243 | No Acquirer | March 20, 2009 | August 17, 2012
Freedom Bank of Georgia | Commerce | GA | 57558 | Northeast Georgia Bank | March 6, 2009 | August 17, 2012
Security Savings Bank | Henderson | NV | 34820 | Bank of Nevada | February 27, 2009 | September 7, 2012
Heritage Community Bank | Glenwood | IL | 20078 | MB Financial Bank, N.A. | February 27, 2009 | August 17, 2012
Silver Falls Bank | Silverton | OR | 35399 | Citizens Bank | February 20, 2009 | August 17, 2012
Pinnacle Bank of Oregon | Beaverton | OR | 57342 | Washington Trust Bank of Spokane | February 13, 2009 | August 17, 2012
Corn Belt Bank & Trust Co. | Pittsfield | IL | 16500 | The Carlinville National Bank | February 13, 2009 | August 17, 2012
Riverside Bank of the Gulf Coast | Cape Coral | FL | 34563 | TIB Bank | February 13, 2009 | August 17, 2012
Sherman County Bank | Loup City | NE | 5431 | Heritage Bank | February 13, 2009 | August 17, 2012
County Bank | Merced | CA | 22574 | Westamerica Bank | February 6, 2009 | September 4, 2012
Alliance Bank | Culver City | CA | 23124 | California Bank & Trust | February 6, 2009 | August 16, 2012
FirstBank Financial Services | McDonough | GA | 57017 | Regions Bank | February 6, 2009 | August 16, 2012
Ocala National Bank | Ocala | FL | 26538 | CenterState Bank of Florida, N.A. | January 30, 2009 | September 4, 2012
Suburban FSB | Crofton | MD | 30763 | Bank of Essex | January 30, 2009 | August 16, 2012
MagnetBank | Salt Lake City | UT | 58001 | No Acquirer | January 30, 2009 | August 16, 2012
1st Centennial Bank | Redlands | CA | 33025 | First California Bank | January 23, 2009 | August 16, 2012
Bank of Clark County | Vancouver | WA | 34959 | Umpqua Bank | January 16, 2009 | August 16, 2012
National Bank of Commerce | Berkeley | IL | 19733 | Republic Bank of Chicago | January 16, 2009 | August 16, 2012
Sanderson State Bank En Espanol | Sanderson | TX | 11568 | The Pecos County State Bank | December 12, 2008 | September 4, 2012
Haven Trust Bank | Duluth | GA | 35379 | Branch Banking & Trust Company, (BB&T) | December 12, 2008 | August 16, 2012
First Georgia Community Bank | Jackson | GA | 34301 | United Bank | December 5, 2008 | August 16, 2012
PFF Bank & Trust | Pomona | CA | 28344 | U.S. Bank, N.A. | November 21, 2008 | January 4, 2013
Downey Savings & Loan | Newport Beach | CA | 30968 | U.S. Bank, N.A. | November 21, 2008 | January 4, 2013
Community Bank | Loganville | GA | 16490 | Bank of Essex | November 21, 2008 | September 4, 2012
Security Pacific Bank | Los Angeles | CA | 23595 | Pacific Western Bank | November 7, 2008 | August 28, 2012
Franklin Bank, SSB | Houston | TX | 26870 | Prosperity Bank | November 7, 2008 | August 16, 2012
Freedom Bank | Bradenton | FL | 57930 | Fifth Third Bank | October 31, 2008 | August 16, 2012
Alpha Bank & Trust | Alpharetta | GA | 58241 | Stearns Bank, N.A. | October 24, 2008 | August 16, 2012
Meridian Bank | Eldred | IL | 13789 | National Bank | October 10, 2008 | May 31, 2012
Main Street Bank | Northville | MI | 57654 | Monroe Bank & Trust | October 10, 2008 | August 16, 2012
Washington Mutual Bank (Including its subsidiary Washington Mutual Bank FSB) | Henderson | NV | 32633 | JP Morgan Chase Bank | September 25, 2008 | August 16, 2012
Ameribank | Northfork | WV | 6782 | The Citizens Savings Bank Pioneer Community Bank, Inc. | September 19, 2008 | August 16, 2012
Silver State Bank En Espanol | Henderson | NV | 34194 | Nevada State Bank | September 5, 2008 | August 16, 2012
Integrity Bank | Alpharetta | GA | 35469 | Regions Bank | August 29, 2008 | August 16, 2012
Columbian Bank & Trust | Topeka | KS | 22728 | Citizens Bank & Trust | August 22, 2008 | August 16, 2012
First Priority Bank | Bradenton | FL | 57523 | SunTrust Bank | August 1, 2008 | August 16, 2012
First Heritage Bank, NA | Newport Beach | CA | 57961 | Mutual of Omaha Bank | July 25, 2008 | August 28, 2012
First National Bank of Nevada | Reno | NV | 27011 | Mutual of Omaha Bank | July 25, 2008 | August 28, 2012
IndyMac Bank | Pasadena | CA | 29730 | OneWest Bank, FSB | July 11, 2008 | August 28, 2012
First Integrity Bank, NA | Staples | MN | 12736 | First International Bank and Trust | May 30, 2008 | August 28, 2012
ANB Financial, NA | Bentonville | AR | 33901 | Pulaski Bank and Trust Company | May 9, 2008 | August 28, 2012
Hume Bank | Hume | MO | 1971 | Security Bank | March 7, 2008 | August 28, 2012
Douglass National Bank | Kansas City | MO | 24660 | Liberty Bank and Trust Company | January 25, 2008 | October 26, 2012
Miami Valley Bank | Lakeview | OH | 16848 | The Citizens Banking Company | October 4, 2007 | August 28, 2012
NetBank | Alpharetta | GA | 32575 | ING DIRECT | September 28, 2007 | August 28, 2012
Metropolitan Savings Bank | Pittsburgh | PA | 35353 | Allegheny Valley Bank of Pittsburgh | February 2, 2007 | October 27, 2010
Bank of Ephraim | Ephraim | UT | 1249 | Far West Bank | June 25, 2004 | April 9, 2008
Reliance Bank | White Plains | NY | 26778 | Union State Bank | March 19, 2004 | April 9, 2008
Guaranty National Bank of Tallahassee | Tallahassee | FL | 26838 | Hancock Bank of Florida | March 12, 2004 | June 5, 2012
Dollar Savings Bank | Newark | NJ | 31330 | No Acquirer | February 14, 2004 | April 9, 2008
Pulaski Savings Bank | Philadelphia | PA | 27203 | Earthstar Bank | November 14, 2003 | July 22, 2005
First National Bank of Blanchardville | Blanchardville | WI | 11639 | The Park Bank | May 9, 2003 | June 5, 2012
Southern Pacific Bank | Torrance | CA | 27094 | Beal Bank | February 7, 2003 | October 20, 2008
Farmers Bank of Cheneyville | Cheneyville | LA | 16445 | Sabine State Bank & Trust | December 17, 2002 | October 20, 2004
Bank of Alamo | Alamo | TN | 9961 | No Acquirer | November 8, 2002 | March 18, 2005
AmTrade International Bank En Espanol | Atlanta | GA | 33784 | No Acquirer | September 30, 2002 | September 11, 2006
Universal Federal Savings Bank | Chicago | IL | 29355 | Chicago Community Bank | June 27, 2002 | April 9, 2008
Connecticut Bank of Commerce | Stamford | CT | 19183 | Hudson United Bank | June 26, 2002 | February 14, 2012
New Century Bank | Shelby Township | MI | 34979 | No Acquirer | March 28, 2002 | March 18, 2005
Net 1st National Bank | Boca Raton | FL | 26652 | Bank Leumi USA | March 1, 2002 | April 9, 2008
NextBank, NA | Phoenix | AZ | 22314 | No Acquirer | February 7, 2002 | August 27, 2010
Oakwood Deposit Bank Co. | Oakwood | OH | 8966 | The State Bank & Trust Company | February 1, 2002 | October 25, 2012
Bank of Sierra Blanca | Sierra Blanca | TX | 22002 | The Security State Bank of Pecos | January 18, 2002 | November 6, 2003
Hamilton Bank, NA En Espanol | Miami | FL | 24382 | Israel Discount Bank of New York | January 11, 2002 | June 5, 2012
Sinclair National Bank | Gravette | AR | 34248 | Delta Trust & Bank | September 7, 2001 | February 10, 2004
Superior Bank, FSB | Hinsdale | IL | 32646 | Superior Federal, FSB | July 27, 2001 | June 5, 2012
Malta National Bank | Malta | OH | 6629 | North Valley Bank | May 3, 2001 | November 18, 2002
First Alliance Bank & Trust Co. | Manchester | NH | 34264 | Southern New Hampshire Bank & Trust | February 2, 2001 | February 18, 2003
National State Bank of Metropolis | Metropolis | IL | 3815 | Banterra Bank of Marion | December 14, 2000 | March 17, 2005
Bank of Honolulu | Honolulu | HI | 21029 | Bank of the Orient | October 13, 2000 | March 17, 2005

Last Updated 05/31/2013
cservicefdicdal@fdic.gov